@@ -6,6 +6,8 @@ Module implementing MainWindow.
 import math
 import sys
 import EXIF
+import operator
+import os
 from PIL import Image, ImageEnhance, ImageDraw
 
 from PyQt4 import QtGui
@@ -72,9 +74,11 @@ class MainWindow(QMainWindow, Ui_MainWindow):
     valSa =0
     valRot = 0
     valOrient = 0
+    valBW = "L"
     wMaximized = True
     lockUpdating = False
     curImageLoc ="ui/resources/landscapeRepo.jpg"
+    plotIm = Image.open(os.getcwd()+"/ui/resources/graph.png") 
     curIm =""
     curThumb = ""
     valCurTab=0
@@ -86,8 +90,12 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         QMainWindow.__init__(self, parent)
         self.setupUi(self)
         self.ImageOpen(self.curImageLoc)
+        self.postSetup()
         self.ImageDisplayRefresh()
     
+    def postSetup(self):
+        self.tabStrip.setCurrentIndex(0)
+        
     def showUpdateLabel(self, show,  thumb):
         self.lockUpdating = show
         if (thumb == True):
@@ -111,45 +119,58 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         Slot documentation goes here.
         """
-        pil_img = Image.open(self.curImageLoc)
-        self.photo.setPixmap(pil2qpixmap(pil_img))
+        self.valBW = "L"
+        self.BWApply(self.curThumb,  self.valBW,  False)
     
     @pyqtSignature("")
     def on_btn_Red_released(self):
         """
         Slot documentation goes here.
         """
-        if  (self.lockUpdating == False):
-            self.showUpdateLabel(True)
-            im = self.curIm #Image.open(self.curImageLoc)
-            source = im.split()
-            R, G, B = 0, 1, 2
-
-            out = source[R].point(lambda i: i *valToScalar(self.valR))
-            source[R].paste(out, None, None)
-            
-            im = Image.merge(im.mode, source)
-            self.curIm = im
-            self.photo.setPixmap(pil2qpixmap(self.curIm))
-        
-            self.showUpdateLabel(False)
+        self.valBW = "R"
+        self.BWApply(self.curThumb,  self.valBW,  False)
     
     @pyqtSignature("")
     def on_btn_Green_released(self):
         """
         Slot documentation goes here.
         """
-        # TODO: not implemented yet
-        raise NotImplementedError
+        self.valBW = "G"
+        self.BWApply(self.curThumb,  self.valBW,  False)
     
     @pyqtSignature("")
     def on_btn_Blue_released(self):
         """
         Slot documentation goes here.
         """
-        # TODO: not implemented yet
-        raise NotImplementedError
+        self.valBW = "B"
+        self.BWApply(self.curThumb,  self.valBW,  False)
  
+    @pyqtSignature("")
+    def on_btn_Yellow_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.valBW = "Y"
+        self.BWApply(self.curThumb,  self.valBW,  False)
+    
+    @pyqtSignature("")
+    def on_btn_Cyan_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.valBW = "C"
+        self.BWApply(self.curThumb,  self.valBW,  False)
+    
+    @pyqtSignature("")
+    def on_btn_Magenta_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.valBW = "M"
+        self.BWApply(self.curThumb,  self.valBW,  False)
+
+
     @pyqtSignature("")
     def on_btnLevelApply_released(self):
         """
@@ -157,10 +178,100 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         if (self.valCurTab == 5):
             self.RotateApply(self.valRot)
+        elif (self.valCurTab == 1):
+            self.BWApply(self.curIm, self.valBW,  True)
         else:
-            self.LevelApply(self.curIm,  True)
-           
-           
+            self.LevelApply(self.curIm,  True)           
+    
+    
+    @pyqtSignature("")
+    def BWApply(self, imageToEdit,  cSource,  UpdateRealImage):
+        """
+        Slot documentation goes here.
+        """
+        if  (self.lockUpdating == False):
+            if (UpdateRealImage == True):
+                self.showUpdateLabel(True,  False)
+            else:
+                self.showUpdateLabel(True,  True)
+                
+            im = imageToEdit
+            source = im.split()
+            R, G, B = 0, 1, 2
+            imCMYK=im.convert("CMYK")
+            C, M, Y, K = imCMYK.split()
+            N =  Image.new('L', im.size, (0))
+            
+            
+            if cSource == "R":
+                out0=source[R].point(lambda i: i * 3)
+                source[R].paste(out0,  None,  None)
+                out1=source[G].point(lambda i: i * 0)
+                source[G].paste(out1,  None,  None)
+                out2=source[B].point(lambda i: i * 0)
+                source[B].paste(out2,  None,  None)
+                im=Image.merge("RGB", (out0 ,  source[G],  source[B] ))
+                im=im.convert("L")
+            elif cSource == "G":
+                out=source[R].point(lambda i: i * 1)
+                source[R].paste(out,  None,  None)
+                out=source[G].point(lambda i: i * 1.9)
+                source[G].paste(out,  None,  None)
+                out=source[B].point(lambda i: i * 1)
+                source[B].paste(out,  None,  None)
+                im=Image.merge("RGB", (source[R] ,  source[G],  source[B] ))
+                im=im.convert("L")
+            elif cSource == "B":
+                #source[B].point(lambda i: i * 1.2)
+                im = source[R].convert("L")
+            elif cSource == "C":
+                source[B].point(lambda i: i * 1.2)
+                source[G].point(lambda i: i * 1.2)
+                out = Image.merge("RGB", (N, source[G],  source[B]) )
+                im = out.convert("L")
+            elif cSource == "BC":
+                out = Image.merge("RGB", (N, source[G],  source[B]) )
+                im = out.convert("L")
+            elif cSource == "BM":
+                source[R].point(lambda i: i +source[G].getpixel((0,0)) * .33)
+                source[B].point(lambda i: i +source[G].getpixel((0,0)) * .66)
+                out = Image.merge("RGB", (source[R], N,  source[B]) )
+                im = out.convert("L")
+            elif cSource == "M":
+                source[R].point(lambda i: i +source[G].getpixel((0,0)) * .5)
+                source[B].point(lambda i: i +source[G].getpixel((0,0)) * .5)
+                out = Image.merge("RGB", (source[R], N,  source[B])  )
+                im = out.convert("L")
+            elif cSource == "RM":
+                source[R].point(lambda i: i +source[G].getpixel((0,0)) * .33)
+                source[B].point(lambda i: i +source[G].getpixel((0,0)) * .66)
+                out = Image.merge("RGB", (source[R], N,  source[B])  )
+                im = out.convert("L")
+            elif cSource == "RY":
+                out = Image.merge("RGB", (source[R], source[G],  N) )
+                im = out.convert("L")
+            elif cSource == "Y":
+                source[R].point(lambda i: i * 1.66)
+                source[G].point(lambda i: i * 1.66)
+                out = Image.merge("RGB", (source[R], source[G],  N) )
+                im = out.convert("L")
+            elif cSource == "GY":
+                out = Image.merge("RGB", (source[R], source[G],  N) )
+                im = out.convert("L")                
+            elif cSource == "GC":
+                out = Image.merge("RGB", (N, source[G],  source[B]) )
+                im = out.convert("L")    
+            
+            im = im.convert("RGB")
+
+            
+            if (UpdateRealImage == True):
+                self.photo.setPixmap(pil2qpixmap(im))
+                self.showUpdateLabel(False,  False)
+            else:
+                self.photo_Thumb.setPixmap(pil2qpixmap(im))
+                self.showUpdateLabel(False,  True)
+    
     @pyqtSignature("")
     def LevelApply(self, imageToEdit,  UpdateRealImage):
         """
@@ -250,8 +361,12 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         Slot documentation goes here.
         """
-        if (index==7):
+        if (index==9):
             self.frameExitRequest.setGeometry(QtCore.QRect(0, 0, 800, 480))
+        elif  (index==6):
+            self.ReturnHistPlots()
+        elif (index==8):
+            self.AnimateTab()
         else:
             self.valCurTab = index
         
@@ -320,7 +435,8 @@ class MainWindow(QMainWindow, Ui_MainWindow):
                     self.listEXIFData.addItem(newItem)
                     self.listView
             except Exception, e:
-                print "EXIF Error"
+                continue
+                #print "EXIF Error"
       
         self.ImageLoad(self.curIm)
       
@@ -358,17 +474,10 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         Slot documentation goes here.
         """
         if (index == 0):
-            self.tabPhoto.setGeometry(QtCore.QRect(0, 40, 321, 491))
-            self.tabStrip.setGeometry(QtCore.QRect(320, 40, 561, 481))
-            self.photo.repaint()
-            self.photo_Orig.repaint()
+            self.FullScreenToggle(False)
         else:
-            self.tabPhoto.setGeometry(QtCore.QRect(0, 40, 800, 491))
-            self.tabStrip.setGeometry(QtCore.QRect(320, 80, 561, 481))
-            
-        self.tabPhoto.repaint()
-        self.tabStrip.repaint()
-        self.repaint()
+            self.FullScreenToggle(True)
+
 #+++++++++++++++++++++++ END of Class    
     
 
@@ -486,115 +595,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         elif( theta >= (math.pi + pi2)):  # 4.71 - 6.28 ok 
             return([botOps, botAdj, int(w-botOps),  int(h-botAdj)]) 
 
-            
-            
 
-
-#            w, h = im.size
-#            draw = ImageDraw.Draw(im)
-#            theta =math.radians(rotation)
-#
-#            cos = math.cos(theta)
-#            sin = math.sin(theta)
-#            W = w
-#            H = h
-#            h0 = (H*cos-W*sin)/(cos*cos-sin*sin)
-#            w0 = (W-h0*sin)/cos
-#
-#            X = 0
-#            Y = 0
-#            x1 = abs(h0*sin)
-#            y1 = abs(w0*sin)
-#            x2 = abs(h0*sin)
-#            y2 = abs(h0*cos)
-#
-#            #im=im.crop((int(x1), int(y1), int(x2), int(y2)))
-#            draw.rectangle([int(x1), int(y1), int(x2), int(y2)])      
-#            theta = math.radians(value)
-#            #Calc Ops and Adjacent sides of triangle from Height.
-#
-#
-#            h_new = h*abs(math.cos(theta)) + w*abs(math.sin(theta)) 
-#            w_new = w*abs(math.cos(theta)) + h*abs(math.sin(theta))
-#            self.lcdRot_1.setText(str(round(theta, 2)))
-#            self.lcdRot_2.setText(str(round(value, 2)))
-#            self.lcdRot_3.setText(str(round(h_new, 2)))
-#            self.lcdRot_4.setText(str(round(w_new, 2)))
-#
-#            h_rec = round((h - (h * (h/h_new)))/2)
-#            w_rec = round((w - (w * (w/w_new)))/2)
-            
-
-#            botOps = round(abs(h * math.sin(theta))/2)
-#            botAdj = round(abs(h * math.cos(theta))/2)
-#
-#            topOps = round(abs(w * math.sin(theta))/2)
-#            topAdj = round(abs(w * math.cos(theta))/2)
-            
-#            pi2 = math.pi/2
-#            if( theta >= 0.0 and theta < pi2 ):
-#                draw.rectangle([botOps,topOps, int(w-botOps),  int(h-topOps)]) 
-#            elif( theta >= pi2 and theta < math.pi):
-#                draw.rectangle([botOps, botAdj, int(w-botOps),  int(h-botAdj)]) 
-#            elif( theta >= math.pi and theta < (math.pi + pi2) ):
-#                draw.rectangle([botOps, botAdj, int(w-botOps),  int(h-botAdj)]) 
-#            elif( theta >= (math.pi + pi2)):
-#                draw.rectangle([botOps, botAdj, int(w-botOps),  int(h-botAdj)]) 
-#                    
-
-#enhancer = ImageEnhance.Sharpness(image)
-
-        #        for i in range(8):
-        #            factor = i / 4.0
-        #            enhancer.enhance(factor)
-        #            
-
-
-        # multiply each pixel by 1.2
-        # out = im.point(lambda i: i * 1.2)
-        # split the image into individual bands
-        # select regions where red is less than 100
-        # QtGui.QMessageBox.information(self, "Loading Data", "Please wait while the data is retrieved...")
-        # self.refresh()
-        # mask = source[R].point(lambda i: i < 100 and 255)
-        # mask = source[G].point(lambda i: i < 100 and 255)
-        # out = source[G].point(lambda i: i * 0.01*self.valG)
-        # source[G].paste(out, None, mask)
-        # mask = source[B].point(lambda i: i < 100 and 255)
-        # out = source[B].point(lambda i: i * 0.01*self.valB)
-        # source[B].paste(out, None, mask)
-        # imout = im.point(lambda i: expression and 255)
-    
-    
-    
-
-        
-        
-        
-        #e2 = "xyz.jpg"
-        #im = Image.open(file2)
-        #enhancer = ImageEnhance.Brightness(im)
-        #bright_im = enhancer.enhance(0.5) #any value you want
-        #sharp_im = bright_im.filter(ImageFilter.SHARPEN)
-        #sharp_im.save("xyz1.jpg",quality=100)
-
-        #im2 = im.filter(ImageFilter.MinFilter(3))
-        #im2 = im.filter(ImageFilter.MinFilter(3))
-        #im3 = im.filter(ImageFilter.MinFilter) # same as MinFilter(3)
-
-
-        #Enhance(self, im, "Contrast", ImageEnhance.Contrast, -1.0, 3.0)
-                    
-
-        #Enhance(root, im, "Color", ImageEnhance.Color, 0.0, 4.0).pack()
-        #Enhance(Toplevel(), im, "Sharpness", ImageEnhance.Sharpness, -2.0, 2.0).pack()
-        #Enhance(Toplevel(), im, "Brightness", ImageEnhance.Brightness, -1.0, 3.0).pack()
-        #Enhance(Toplevel(), im, "Contrast", ImageEnhance.Contrast, -1.0, 3.0).pack()
-
-
-#cp -r  /home/user/MyDocs/code/svn/ansela/trunk/* /home/user/MyDocs/code/svn/ansela/packaging/anselA/src/opt/anselA/
-    
-    
     @pyqtSignature("")
     def on_btnExitCancel_released(self):
         self.tabStrip.setCurrentIndex(self.valCurTab)
@@ -603,3 +604,194 @@ class MainWindow(QMainWindow, Ui_MainWindow):
     @pyqtSignature("")
     def on_btnExitGo_released(self):
         sys.exit()
+    
+    @pyqtSignature("")
+    def on_btn_rot_none_released(self):
+        """
+        Slot documentation goes here.
+        """
+        # TODO: not implemented yet
+        raise NotImplementedError
+    
+    @pyqtSignature("")
+    def on_btn_rot_Vert_released(self):
+        """
+        Slot documentation goes here.
+        """
+        # TODO: not implemented yet
+        raise NotImplementedError
+    
+    @pyqtSignature("")
+    def on_btn_rot_90cw_released(self):
+        """
+        Slot documentation goes here.
+        """
+        # TODO: not implemented yet
+        raise NotImplementedError
+    
+    @pyqtSignature("")
+    def on_btn_rot_90ccw_released(self):
+        """
+        Slot documentation goes here.
+        """
+        # TODO: not implemented yet
+        raise NotImplementedError
+    
+    @pyqtSignature("")
+    def on_btn_rot_Horz_pressed(self):
+        """
+        Slot documentation goes here.
+        """
+        
+        #out = im.transpose(Image.FLIP_LEFT_RIGHT)
+        #out = im.transpose(Image.FLIP_TOP_BOTTOM)
+        #out = im.transpose(Image.ROTATE_90)
+        #out = im.transpose(Image.ROTATE_180)
+        #out = im.transpose(Image.ROTATE_270)
+
+    
+    @pyqtSignature("")
+    def on_btn_rot_180_released(self):
+        """
+        Slot documentation goes here.
+        """
+        # TODO: not implemented yet
+        raise NotImplementedError
+    
+    @pyqtSignature("")
+    def on_btnFullScreen_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.FullScreenToggle(True)
+    
+    @pyqtSignature("")
+    def on_btnFullScreenClose_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.FullScreenToggle(False)
+
+    @pyqtSignature("")
+    def FullScreenToggle(self,  Show):
+        """
+        Slot documentation goes here.
+        """
+        if (Show):
+            self.tabPhoto.setCurrentIndex(1)
+            self.tabPhoto.setGeometry(QtCore.QRect(0, 40, 800, 480))    
+            self.tabStrip.setGeometry(QtCore.QRect(190, 120, 691, 491))
+        else:
+            self.tabPhoto.setGeometry(QtCore.QRect(0, 0, 0, 0))
+            self.tabStrip.setGeometry(QtCore.QRect(190, 40, 691, 491))
+            self.photo.repaint()
+            self.photo_Orig.repaint()
+            
+        self.tabPhoto.repaint()
+        self.tabStrip.repaint()
+        self.repaint()
+    
+    @pyqtSignature("")
+    def on_btn_BC_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.valBW = "BC"
+        self.BWApply(self.curThumb,  self.valBW,  False)
+    
+    @pyqtSignature("")
+    def on_btn_GC_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.valBW = "GC"
+        self.BWApply(self.curThumb,  self.valBW,  False)
+    
+    @pyqtSignature("")
+    def on_btn_GY_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.valBW = "GY"
+        self.BWApply(self.curThumb,  self.valBW,  False)
+    
+    @pyqtSignature("")
+    def on_btn_BM_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.valBW = "BM"
+        self.BWApply(self.curThumb,  self.valBW,  False)
+        
+    @pyqtSignature("")
+    def on_btn_RM_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.valBW = "RM"
+        self.BWApply(self.curThumb,  self.valBW,  False)
+    
+    @pyqtSignature("")
+    def on_btn_RY_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.valBW = "RY"
+        self.BWApply(self.curThumb,  self.valBW,  False)
+
+    @pyqtSignature("")
+    def ReturnHistPlots(self):
+        """
+        Slot documentation goes here.
+        """
+        histo=self.curIm.histogram()
+        OrignX=37
+        OrignY=108
+
+        ScaleMax=(max(histo)/100)  #256)
+        print ScaleMax
+
+        plotList =list()
+        valX=0
+
+        for valY in histo:
+            ProcVal =int(valY/ScaleMax)
+            plotList.append(ProcVal)
+    
+        plotR = Image.new("RGB", self.plotIm.size)
+        plotG = Image.new("RGB", self.plotIm.size)
+        plotB = Image.new("RGB", self.plotIm.size)
+        
+        plotR.paste(self.plotIm)# = self.poltIm.copy()
+        plotG.paste(self.plotIm)
+        plotB.paste(self.plotIm)
+        
+        drawR = ImageDraw.Draw(plotR)
+        drawG = ImageDraw.Draw(plotG)
+        drawB = ImageDraw.Draw(plotB)        
+
+        valX=0
+        sortCol = list()
+        for x in range(255):
+            plotX =OrignX + x
+            drawR.line([plotX, OrignY, plotX, OrignY-plotList[x]], fill="red")
+            drawG.line([plotX, OrignY, plotX, OrignY-plotList[x+256]], fill="green")
+            drawB.line([plotX, OrignY, plotX, OrignY-plotList[x+512]], fill="blue")
+        del drawR
+        del drawG
+        del drawB
+
+        #return plotIm
+        
+        self.graphRed.setPixmap(pil2qpixmap(plotR.convert("RGB")))
+        self.graphGreen.setPixmap(pil2qpixmap(plotG.convert("RGB")))
+        self.graphBlue.setPixmap(pil2qpixmap(plotB.convert("RGB")))
+    
+        
+#        for x in range(255):
+#            plotX =OrignX + x
+#            sortCol=sorted(((x,plotList[x],"red"),(x+256,plotList[x+256],"green"),(x+512,plotList[x+512],"blue")), key=operator.itemgetter(1))
+#            draw.line([plotX, OrignY, plotX, OrignY-sortCol[2][1]], fill=sortCol[2][2])
+#            draw.line([plotX, OrignY, plotX, OrignY-sortCol[1][1]], fill=sortCol[1][2])
+#            draw.line([plotX, OrignY, plotX, OrignY-sortCol[0][1]], fill=sortCol[0][2])
+#        del draw 
